@@ -1,6 +1,8 @@
 from .attribute import Attribute
+from .flock import Flock
 from .hook import Hook
 from . import attribute
+from . import flock
 from . import log
 from . import random
 from . import gpus
